Class: Google::Apis::SecuritypostureV1::ListReportsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::ListReportsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
Response message for ListReports.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A pagination token.
-
#reports ⇒ Array<Google::Apis::SecuritypostureV1::Report>
The list of Report resources.
-
#unreachable ⇒ Array<String>
Locations that were temporarily unavailable and could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReportsResponse
constructor
A new instance of ListReportsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReportsResponse
Returns a new instance of ListReportsResponse.
793 794 795 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A pagination token. To retrieve the next page of results, call the method
again with this token.
Corresponds to the JSON property nextPageToken
781 782 783 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 781 def next_page_token @next_page_token end |
#reports ⇒ Array<Google::Apis::SecuritypostureV1::Report>
The list of Report resources.
Corresponds to the JSON property reports
786 787 788 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 786 def reports @reports end |
#unreachable ⇒ Array<String>
Locations that were temporarily unavailable and could not be reached.
Corresponds to the JSON property unreachable
791 792 793 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 791 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
798 799 800 801 802 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 798 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @reports = args[:reports] if args.key?(:reports) @unreachable = args[:unreachable] if args.key?(:unreachable) end |