Class: Google::Apis::SecuritypostureV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
Metadata for an Operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error_message ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
962 963 964 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. The API version used to start the operation.
Corresponds to the JSON property apiVersion
921 922 923 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 921 def api_version @api_version end |
#create_time ⇒ String
Output only. The time at which the operation was created.
Corresponds to the JSON property createTime
926 927 928 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 926 def create_time @create_time end |
#end_time ⇒ String
Output only. The time at which the operation finished running.
Corresponds to the JSON property endTime
931 932 933 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 931 def end_time @end_time end |
#error_message ⇒ String
Output only. An error message. Returned when a PostureDeployment enters a
failure state like UPDATE_FAILED.
Corresponds to the JSON property errorMessage
937 938 939 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 937 def @error_message end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Whether a request to cancel the operation has been received. For
operations that have been cancelled successfully, the Operation.error field
contains the error code CANCELLED.
Corresponds to the JSON property requestedCancellation
944 945 946 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 944 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. The status of the operation, if any.
Corresponds to the JSON property statusMessage
950 951 952 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 950 def @status_message end |
#target ⇒ String
Output only. The server-defined resource path for the target of the operation.
Corresponds to the JSON property target
955 956 957 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 955 def target @target end |
#verb ⇒ String
Output only. The name of the action executed by the operation.
Corresponds to the JSON property verb
960 961 962 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 960 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
967 968 969 970 971 972 973 974 975 976 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 967 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error_message = args[:error_message] if args.key?(:error_message) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |