Class: Google::Apis::SecuritypostureV1::PolicyDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb

Overview

Details of a policy that was violated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyDetails

Returns a new instance of PolicyDetails.



1098
1099
1100
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliance_standardsArray<String>

The compliance standards that the policy maps to. For example, CIS-2.0 1.15. Corresponds to the JSON property complianceStandards

Returns:

  • (Array<String>)


1079
1080
1081
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1079

def compliance_standards
  @compliance_standards
end

#constraintString

Information about the constraint that was violated. The format of this information can change at any time without prior notice. Your application must not depend on this information in any way. Corresponds to the JSON property constraint

Returns:

  • (String)


1086
1087
1088
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1086

def constraint
  @constraint
end

#constraint_typeString

The type of constraint that was violated. Corresponds to the JSON property constraintType

Returns:

  • (String)


1091
1092
1093
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1091

def constraint_type
  @constraint_type
end

#descriptionString

A description of the policy. Corresponds to the JSON property description

Returns:

  • (String)


1096
1097
1098
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1096

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1103
1104
1105
1106
1107
1108
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1103

def update!(**args)
  @compliance_standards = args[:compliance_standards] if args.key?(:compliance_standards)
  @constraint = args[:constraint] if args.key?(:constraint)
  @constraint_type = args[:constraint_type] if args.key?(:constraint_type)
  @description = args[:description] if args.key?(:description)
end