Class: Google::Apis::SecuritypostureV1::Posture
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::Posture
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
The details of a posture.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#categories ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#policy_sets ⇒ Array<Google::Apis::SecuritypostureV1::PolicySet>
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#revision_id ⇒ String
Output only.
-
#state ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Posture
constructor
A new instance of Posture.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Posture
Returns a new instance of Posture.
1213 1214 1215 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. The user-specified annotations for the posture. For details about
the values you can use in an annotation, see AIP-148: Standard fields.
Corresponds to the JSON property annotations
1152 1153 1154 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1152 def annotations @annotations end |
#categories ⇒ Array<String>
Output only. The categories that the posture belongs to, as determined by the
Security Posture API.
Corresponds to the JSON property categories
1158 1159 1160 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1158 def categories @categories end |
#create_time ⇒ String
Output only. The time at which the posture was created.
Corresponds to the JSON property createTime
1163 1164 1165 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1163 def create_time @create_time end |
#description ⇒ String
Optional. A description of the posture.
Corresponds to the JSON property description
1168 1169 1170 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1168 def description @description end |
#etag ⇒ String
Optional. An opaque identifier for the current version of the posture at the
specified revision_id. To prevent concurrent updates from overwriting each
other, always provide the etag when you update a posture. You can also
provide the etag when you delete a posture, to help ensure that you're
deleting the intended version of the posture.
Corresponds to the JSON property etag
1177 1178 1179 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1177 def etag @etag end |
#name ⇒ String
Required. Identifier. The name of the posture, in the format organizations/
organization/locations/global/postures/posture_id`.
Corresponds to the JSON propertyname`
1183 1184 1185 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1183 def name @name end |
#policy_sets ⇒ Array<Google::Apis::SecuritypostureV1::PolicySet>
Required. The PolicySet resources that the posture includes.
Corresponds to the JSON property policySets
1188 1189 1190 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1188 def policy_sets @policy_sets end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether the posture is in the process of being updated.
Corresponds to the JSON property reconciling
1193 1194 1195 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1193 def reconciling @reconciling end |
#revision_id ⇒ String
Output only. Immutable. An opaque eight-character string that identifies the
revision of the posture. A posture can have multiple revisions; when you
deploy a posture, you deploy a specific revision of the posture.
Corresponds to the JSON property revisionId
1201 1202 1203 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1201 def revision_id @revision_id end |
#state ⇒ String
Required. The state of the posture at the specified revision_id.
Corresponds to the JSON property state
1206 1207 1208 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1206 def state @state end |
#update_time ⇒ String
Output only. The time at which the posture was last updated.
Corresponds to the JSON property updateTime
1211 1212 1213 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1211 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1218 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @categories = args[:categories] if args.key?(:categories) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @policy_sets = args[:policy_sets] if args.key?(:policy_sets) @reconciling = args[:reconciling] if args.key?(:reconciling) @revision_id = args[:revision_id] if args.key?(:revision_id) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |