Class: Google::Apis::SecuritypostureV1::PostureDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb

Overview

Details of a posture deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostureDetails

Returns a new instance of PostureDetails.



1388
1389
1390
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_setString

The identifier for the PolicySet that the relevant policy belongs to. Corresponds to the JSON property policySet

Returns:

  • (String)


1362
1363
1364
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1362

def policy_set
  @policy_set
end

#postureString

The posture used in the deployment, in the format organizations/organization /locations/global/postures/posture_id`. Corresponds to the JSON propertyposture`

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1368

def posture
  @posture
end

#posture_deploymentString

The name of the posture deployment, in the format organizations/organization /locations/global/postureDeployments/deployment_id`. Corresponds to the JSON propertypostureDeployment`

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1374

def posture_deployment
  @posture_deployment
end

#posture_deployment_target_resourceString

The organization, folder, or project where the posture is deployed. Uses one of the following formats: * organizations/organization_number* `folders/` folder_number * projects/project_number` Corresponds to the JSON propertypostureDeploymentTargetResource`

Returns:

  • (String)


1381
1382
1383
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1381

def posture_deployment_target_resource
  @posture_deployment_target_resource
end

#posture_revision_idString

The revision ID of the posture used in the deployment. Corresponds to the JSON property postureRevisionId

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1386

def posture_revision_id
  @posture_revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1393
1394
1395
1396
1397
1398
1399
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1393

def update!(**args)
  @policy_set = args[:policy_set] if args.key?(:policy_set)
  @posture = args[:posture] if args.key?(:posture)
  @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment)
  @posture_deployment_target_resource = args[:posture_deployment_target_resource] if args.key?(:posture_deployment_target_resource)
  @posture_revision_id = args[:posture_revision_id] if args.key?(:posture_revision_id)
end