Class: Google::Apis::SecuritypostureV1::PostureTemplate
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::PostureTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
The details of a posture template.
Instance Attribute Summary collapse
-
#categories ⇒ Array<String>
Output only.
-
#description ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#policy_sets ⇒ Array<Google::Apis::SecuritypostureV1::PolicySet>
Output only.
-
#revision_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostureTemplate
constructor
A new instance of PostureTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostureTemplate
Returns a new instance of PostureTemplate.
1439 1440 1441 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categories ⇒ Array<String>
Output only. The categories that the posture template belongs to, as
determined by the Security Posture API.
Corresponds to the JSON property categories
1410 1411 1412 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1410 def categories @categories end |
#description ⇒ String
Output only. A description of the posture template.
Corresponds to the JSON property description
1415 1416 1417 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1415 def description @description end |
#name ⇒ String
Output only. Identifier. The name of the posture template, in the format
organizations/organization/locations/global/postureTemplates/
posture_template`.
Corresponds to the JSON propertyname`
1422 1423 1424 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1422 def name @name end |
#policy_sets ⇒ Array<Google::Apis::SecuritypostureV1::PolicySet>
Output only. The PolicySet resources that the posture template includes.
Corresponds to the JSON property policySets
1427 1428 1429 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1427 def policy_sets @policy_sets end |
#revision_id ⇒ String
Output only. A string that identifies the revision of the posture template.
Corresponds to the JSON property revisionId
1432 1433 1434 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1432 def revision_id @revision_id end |
#state ⇒ String
Output only. The state of the posture template at the specified revision_id.
Corresponds to the JSON property state
1437 1438 1439 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1437 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1444 1445 1446 1447 1448 1449 1450 1451 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1444 def update!(**args) @categories = args[:categories] if args.key?(:categories) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @policy_sets = args[:policy_sets] if args.key?(:policy_sets) @revision_id = args[:revision_id] if args.key?(:revision_id) @state = args[:state] if args.key?(:state) end |