Class: Google::Apis::SecuritypostureV1::Property

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb

Overview

A name-value pair used as a custom source property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Property

Returns a new instance of Property.



1482
1483
1484
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The name of the custom source property. Corresponds to the JSON property name

Returns:

  • (String)


1461
1462
1463
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1461

def name
  @name
end

#value_expressionGoogle::Apis::SecuritypostureV1::Expr

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information. Corresponds to the JSON property valueExpression



1480
1481
1482
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1480

def value_expression
  @value_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1487
1488
1489
1490
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1487

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value_expression = args[:value_expression] if args.key?(:value_expression)
end