Class: Google::Apis::SecuritypostureV1::SecurityHealthAnalyticsCustomModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb

Overview

A custom module for Security Health Analytics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityHealthAnalyticsCustomModule

Returns a new instance of SecurityHealthAnalyticsCustomModule.



1605
1606
1607
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::SecuritypostureV1::CustomConfig

A custom module configuration for Security Health Analytics. Use CustomConfig to create custom detectors that generate custom findings for resources that you specify. Corresponds to the JSON property config



1583
1584
1585
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1583

def config
  @config
end

#display_nameString

Optional. The display name of the custom module. This value is used as the finding category for all the asset violation findings that the custom module returns. The display name must contain between 1 and 128 alphanumeric characters or underscores, and it must start with a lowercase letter. Corresponds to the JSON property displayName

Returns:

  • (String)


1591
1592
1593
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1591

def display_name
  @display_name
end

#idString

Output only. Immutable. The unique identifier for the custom module. Contains 1 to 20 digits. Corresponds to the JSON property id

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1597

def id
  @id
end

#module_enablement_stateString

Whether the custom module is enabled at a specified level of the resource hierarchy. Corresponds to the JSON property moduleEnablementState

Returns:

  • (String)


1603
1604
1605
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1603

def module_enablement_state
  @module_enablement_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1610
1611
1612
1613
1614
1615
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1610

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @module_enablement_state = args[:module_enablement_state] if args.key?(:module_enablement_state)
end