Class: Google::Apis::SecuritypostureV1::SecurityHealthAnalyticsModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb

Overview

A built-in detector for Security Health Analytics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityHealthAnalyticsModule

Returns a new instance of SecurityHealthAnalyticsModule.



1634
1635
1636
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#module_enablement_stateString

Whether the detector is enabled at a specified level of the resource hierarchy. Corresponds to the JSON property moduleEnablementState

Returns:

  • (String)


1625
1626
1627
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1625

def module_enablement_state
  @module_enablement_state
end

#module_nameString

Required. The name of the detector. For example, BIGQUERY_TABLE_CMEK_DISABLED . This field is also used as the finding category for all the asset violation findings that the detector returns. Corresponds to the JSON property moduleName

Returns:

  • (String)


1632
1633
1634
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1632

def module_name
  @module_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1639
1640
1641
1642
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1639

def update!(**args)
  @module_enablement_state = args[:module_enablement_state] if args.key?(:module_enablement_state)
  @module_name = args[:module_name] if args.key?(:module_name)
end