Class: Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
Response message for ListPostureDeployments.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A pagination token.
-
#posture_deployments ⇒ Array<Google::Apis::SecuritypostureV1::PostureDeployment>
The list of PostureDeployment resources.
-
#unreachable ⇒ Array<String>
Locations that were temporarily unavailable and could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPostureDeploymentsResponse
constructor
A new instance of ListPostureDeploymentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPostureDeploymentsResponse
Returns a new instance of ListPostureDeploymentsResponse.
677 678 679 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A pagination token. To retrieve the next page of results, call the method
again with this token.
Corresponds to the JSON property nextPageToken
665 666 667 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 665 def next_page_token @next_page_token end |
#posture_deployments ⇒ Array<Google::Apis::SecuritypostureV1::PostureDeployment>
The list of PostureDeployment resources.
Corresponds to the JSON property postureDeployments
670 671 672 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 670 def posture_deployments @posture_deployments end |
#unreachable ⇒ Array<String>
Locations that were temporarily unavailable and could not be reached.
Corresponds to the JSON property unreachable
675 676 677 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 675 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
682 683 684 685 686 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 682 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @posture_deployments = args[:posture_deployments] if args.key?(:posture_deployments) @unreachable = args[:unreachable] if args.key?(:unreachable) end |