Class: Google::Apis::SecuritypostureV1::PostureDeployment
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::PostureDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
Details for a Posture deployment on an organization, folder, or project. You can deploy at most one posture to each organization, folder, or project. The parent resource for a posture deployment is always the organization, even if the deployment applies to a folder or project.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#categories ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#desired_posture_id ⇒ String
Output only.
-
#desired_posture_revision_id ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#failure_message ⇒ String
Output only.
-
#name ⇒ String
Required.
-
#posture_id ⇒ String
Required.
-
#posture_revision_id ⇒ String
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#target_resource ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostureDeployment
constructor
A new instance of PostureDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostureDeployment
Returns a new instance of PostureDeployment.
1331 1332 1333 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. The user-specified annotations for the posture deployment. For
details about the values you can use in an annotation, see AIP-148: Standard
fields.
Corresponds to the JSON property annotations
1245 1246 1247 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1245 def annotations @annotations end |
#categories ⇒ Array<String>
Output only. The categories that the posture deployment belongs to, as
determined by the Security Posture API.
Corresponds to the JSON property categories
1251 1252 1253 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1251 def categories @categories end |
#create_time ⇒ String
Output only. The time at which the posture deployment was created.
Corresponds to the JSON property createTime
1256 1257 1258 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1256 def create_time @create_time end |
#description ⇒ String
Optional. A description of the posture deployment.
Corresponds to the JSON property description
1261 1262 1263 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1261 def description @description end |
#desired_posture_id ⇒ String
Output only. The posture ID that was specified for the deployment. Present
only if the posture deployment is in a failed state.
Corresponds to the JSON property desiredPostureId
1267 1268 1269 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1267 def desired_posture_id @desired_posture_id end |
#desired_posture_revision_id ⇒ String
Output only. The revision ID of the posture that was specified for the
deployment. Present only if the deployment is in a failed state.
Corresponds to the JSON property desiredPostureRevisionId
1273 1274 1275 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1273 def desired_posture_revision_id @desired_posture_revision_id end |
#etag ⇒ String
Optional. An opaque identifier for the current version of the posture
deployment. To prevent concurrent updates from overwriting each other, always
provide the etag when you update a posture deployment. You can also provide
the etag when you delete a posture deployment, to help ensure that you're
deleting the intended posture deployment.
Corresponds to the JSON property etag
1282 1283 1284 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1282 def etag @etag end |
#failure_message ⇒ String
Output only. A description of why the posture deployment failed. Present only
if the deployment is in a failed state.
Corresponds to the JSON property failureMessage
1288 1289 1290 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1288 def @failure_message end |
#name ⇒ String
Required. Identifier. The name of the posture deployment, in the format
organizations/organization/locations/global/postureDeployments/
deployment_id`.
Corresponds to the JSON propertyname`
1295 1296 1297 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1295 def name @name end |
#posture_id ⇒ String
Required. The posture used in the deployment, in the format organizations/
organization/locations/global/postures/posture_id`.
Corresponds to the JSON propertypostureId`
1301 1302 1303 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1301 def posture_id @posture_id end |
#posture_revision_id ⇒ String
Required. The revision ID of the posture used in the deployment.
Corresponds to the JSON property postureRevisionId
1306 1307 1308 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1306 def posture_revision_id @posture_revision_id end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether the posture deployment is in the process of being updated.
Corresponds to the JSON property reconciling
1311 1312 1313 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1311 def reconciling @reconciling end |
#state ⇒ String
Output only. The state of the posture deployment.
Corresponds to the JSON property state
1317 1318 1319 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1317 def state @state end |
#target_resource ⇒ String
Required. The organization, folder, or project where the posture is deployed.
Uses one of the following formats: * organizations/organization_number* `
folders/`folder_number * projects/project_number`
Corresponds to the JSON propertytargetResource`
1324 1325 1326 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1324 def target_resource @target_resource end |
#update_time ⇒ String
Output only. The time at which the posture deployment was last updated.
Corresponds to the JSON property updateTime
1329 1330 1331 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1329 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1336 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @categories = args[:categories] if args.key?(:categories) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @desired_posture_id = args[:desired_posture_id] if args.key?(:desired_posture_id) @desired_posture_revision_id = args[:desired_posture_revision_id] if args.key?(:desired_posture_revision_id) @etag = args[:etag] if args.key?(:etag) @failure_message = args[:failure_message] if args.key?(:failure_message) @name = args[:name] if args.key?(:name) @posture_id = args[:posture_id] if args.key?(:posture_id) @posture_revision_id = args[:posture_revision_id] if args.key?(:posture_revision_id) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @target_resource = args[:target_resource] if args.key?(:target_resource) @update_time = args[:update_time] if args.key?(:update_time) end |