Class: Google::Apis::SecuritypostureV1::Report
- Inherits:
-
Object
- Object
- Google::Apis::SecuritypostureV1::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securityposture_v1/classes.rb,
lib/google/apis/securityposture_v1/representations.rb,
lib/google/apis/securityposture_v1/representations.rb
Overview
Details of a report.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#iac_validation_report ⇒ Google::Apis::SecuritypostureV1::IaCValidationReport
Details of an infrastructure-as-code (IaC) validation report.
-
#name ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
1518 1519 1520 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the report was created.
Corresponds to the JSON property createTime
1500 1501 1502 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1500 def create_time @create_time end |
#iac_validation_report ⇒ Google::Apis::SecuritypostureV1::IaCValidationReport
Details of an infrastructure-as-code (IaC) validation report.
Corresponds to the JSON property iacValidationReport
1505 1506 1507 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1505 def iac_validation_report @iac_validation_report end |
#name ⇒ String
Required. The name of the report, in the format organizations/organization/
locations/global/reports/report_id`.
Corresponds to the JSON propertyname`
1511 1512 1513 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1511 def name @name end |
#update_time ⇒ String
Output only. The time at which the report was last updated.
Corresponds to the JSON property updateTime
1516 1517 1518 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1516 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1523 1524 1525 1526 1527 1528 |
# File 'lib/google/apis/securityposture_v1/classes.rb', line 1523 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @iac_validation_report = args[:iac_validation_report] if args.key?(:iac_validation_report) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |