Class: Google::Apis::SecuritypostureV1::SecurityPostureService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::SecuritypostureV1::SecurityPostureService
- Defined in:
- lib/google/apis/securityposture_v1/service.rb
Overview
Security Posture API
Defines, assesses, and monitors the overall status of your security in Google Cloud. You can use security postures to evaluate your current cloud security against defined benchmarks and help maintain the level of security that your organization requires.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://securityposture.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_ia_c_validation_report(parent, create_ia_c_validation_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Validates a specified infrastructure-as-code (IaC) configuration, and creates a Report with the validation results.
-
#create_organization_location_posture(parent, posture_object = nil, posture_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Creates a new Posture.
-
#create_organization_location_posture_deployment(parent, posture_deployment_object = nil, posture_deployment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Creates a new PostureDeployment in a given project and location.
-
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Empty
Deletes a long-running operation.
-
#delete_organization_location_posture(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Deletes all revisions of a Posture.
-
#delete_organization_location_posture_deployment(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Deletes a PostureDeployment.
-
#extract_posture(parent, extract_posture_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Extracts existing policies from an organization, folder, or project, and applies them to another organization, folder, or project as a Posture.
-
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_location_posture(name, revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Posture
Gets a single revision of a Posture.
-
#get_organization_location_posture_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::PostureDeployment
Gets details for a PostureDeployment.
-
#get_organization_location_posture_template(name, revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::PostureTemplate
Gets a single revision of a PostureTemplate.
-
#get_organization_location_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Report
Gets details for a Report.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Location
Gets information about a location.
-
#initialize ⇒ SecurityPostureService
constructor
A new instance of SecurityPostureService.
-
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_posture_deployments(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse
Lists every PostureDeployment in a project and location.
-
#list_organization_location_posture_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureRevisionsResponse
Lists all revisions of a single Posture.
-
#list_organization_location_posture_templates(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureTemplatesResponse
Lists every PostureTemplate in a given organization and location.
-
#list_organization_location_postures(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPosturesResponse
Lists the most recent revisions of all Posture resources in a specified organization and location.
-
#list_organization_location_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListReportsResponse
Lists every Report in a given organization and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_organization_location_posture(name, posture_object = nil, revision_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Updates a revision of an existing Posture.
-
#patch_organization_location_posture_deployment(name, posture_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Updates an existing PostureDeployment.
Constructor Details
#initialize ⇒ SecurityPostureService
Returns a new instance of SecurityPostureService.
50 51 52 53 54 55 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 50 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-securityposture_v1', client_version: Google::Apis::SecuritypostureV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
43 44 45 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 43 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
48 49 50 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 48 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 85 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::SecuritypostureV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::SecuritypostureV1::Empty::Representation command.response_class = Google::Apis::SecuritypostureV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_ia_c_validation_report(parent, create_ia_c_validation_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Validates a specified infrastructure-as-code (IaC) configuration, and creates a Report with the validation results. Only Terraform configurations are supported. Only modified assets are validated.
792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 792 def create_ia_c_validation_report(parent, create_ia_c_validation_report_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/reports:createIaCValidationReport', ) command.request_representation = Google::Apis::SecuritypostureV1::CreateIaCValidationReportRequest::Representation command.request_object = create_ia_c_validation_report_request_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_posture(parent, posture_object = nil, posture_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Creates a new Posture.
510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 510 def create_organization_location_posture(parent, posture_object = nil, posture_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/postures', ) command.request_representation = Google::Apis::SecuritypostureV1::Posture::Representation command.request_object = posture_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['parent'] = parent unless parent.nil? command.query['postureId'] = posture_id unless posture_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_posture_deployment(parent, posture_deployment_object = nil, posture_deployment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Creates a new PostureDeployment in a given project and location.
234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 234 def create_organization_location_posture_deployment(parent, posture_deployment_object = nil, posture_deployment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/postureDeployments', ) command.request_representation = Google::Apis::SecuritypostureV1::PostureDeployment::Representation command.request_object = posture_deployment_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['parent'] = parent unless parent.nil? command.query['postureDeploymentId'] = posture_deployment_id unless posture_deployment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
120 121 122 123 124 125 126 127 128 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 120 def delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Empty::Representation command.response_class = Google::Apis::SecuritypostureV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_posture(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Deletes all revisions of a Posture. You can only delete a posture if none of its revisions are deployed.
550 551 552 553 554 555 556 557 558 559 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 550 def delete_organization_location_posture(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_posture_deployment(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Deletes a PostureDeployment.
274 275 276 277 278 279 280 281 282 283 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 274 def delete_organization_location_posture_deployment(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#extract_posture(parent, extract_posture_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Extracts existing policies from an organization, folder, or project, and applies them to another organization, folder, or project as a Posture. If the other organization, folder, or project already has a posture, then the result of the long-running operation is an ALREADY_EXISTS error.
586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 586 def extract_posture(parent, extract_posture_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/postures:extract', ) command.request_representation = Google::Apis::SecuritypostureV1::ExtractPostureRequest::Representation command.request_object = extract_posture_request_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
151 152 153 154 155 156 157 158 159 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 151 def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_posture(name, revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Posture
Gets a single revision of a Posture.
622 623 624 625 626 627 628 629 630 631 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 622 def get_organization_location_posture(name, revision_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Posture::Representation command.response_class = Google::Apis::SecuritypostureV1::Posture command.params['name'] = name unless name.nil? command.query['revisionId'] = revision_id unless revision_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_posture_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::PostureDeployment
Gets details for a PostureDeployment.
306 307 308 309 310 311 312 313 314 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 306 def get_organization_location_posture_deployment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::PostureDeployment::Representation command.response_class = Google::Apis::SecuritypostureV1::PostureDeployment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_posture_template(name, revision_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::PostureTemplate
Gets a single revision of a PostureTemplate.
431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 431 def get_organization_location_posture_template(name, revision_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::PostureTemplate::Representation command.response_class = Google::Apis::SecuritypostureV1::PostureTemplate command.params['name'] = name unless name.nil? command.query['revisionId'] = revision_id unless revision_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Report
Gets details for a Report.
825 826 827 828 829 830 831 832 833 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 825 def get_organization_location_report(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Report::Representation command.response_class = Google::Apis::SecuritypostureV1::Report command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Location
Gets information about a location.
899 900 901 902 903 904 905 906 907 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 899 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecuritypostureV1::Location::Representation command.response_class = Google::Apis::SecuritypostureV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 196 def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::SecuritypostureV1::ListOperationsResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_posture_deployments(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse
Lists every PostureDeployment in a project and location.
347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 347 def list_organization_location_posture_deployments(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/postureDeployments', ) command.response_representation = Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListPostureDeploymentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_posture_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureRevisionsResponse
Lists all revisions of a single Posture.
705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 705 def list_organization_location_posture_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:listRevisions', ) command.response_representation = Google::Apis::SecuritypostureV1::ListPostureRevisionsResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListPostureRevisionsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_posture_templates(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPostureTemplatesResponse
Lists every PostureTemplate in a given organization and location.
473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 473 def list_organization_location_posture_templates(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/postureTemplates', ) command.response_representation = Google::Apis::SecuritypostureV1::ListPostureTemplatesResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListPostureTemplatesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_postures(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListPosturesResponse
Lists the most recent revisions of all Posture resources in a specified organization and location.
664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 664 def list_organization_location_postures(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/postures', ) command.response_representation = Google::Apis::SecuritypostureV1::ListPosturesResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListPosturesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListReportsResponse
Lists every Report in a given organization and location.
866 867 868 869 870 871 872 873 874 875 876 877 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 866 def list_organization_location_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/reports', ) command.response_representation = Google::Apis::SecuritypostureV1::ListReportsResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListReportsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
946 947 948 949 950 951 952 953 954 955 956 957 958 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 946 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::SecuritypostureV1::ListLocationsResponse::Representation command.response_class = Google::Apis::SecuritypostureV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_posture(name, posture_object = nil, revision_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Updates a revision of an existing Posture. If the posture revision that you
update is currently deployed, then a new revision of the posture is created.
To prevent concurrent updates from overwriting each other, always follow the
read-modify-write pattern when you update a posture: 1. Call GetPosture to get
the current version of the posture. 2. Update the fields in the posture as
needed. 3. Call UpdatePosture to update the posture. Ensure that your request
includes the etag value from the GetPosture response. Important: If you
omit the etag when you call UpdatePosture, then the updated posture
unconditionally overwrites the existing posture.
754 755 756 757 758 759 760 761 762 763 764 765 766 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 754 def patch_organization_location_posture(name, posture_object = nil, revision_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecuritypostureV1::Posture::Representation command.request_object = posture_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['name'] = name unless name.nil? command.query['revisionId'] = revision_id unless revision_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_posture_deployment(name, posture_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecuritypostureV1::Operation
Updates an existing PostureDeployment. To prevent concurrent updates from
overwriting each other, always follow the read-modify-write pattern when you
update a posture deployment: 1. Call GetPostureDeployment to get the current
version of the deployment. 2. Update the fields in the deployment as needed. 3.
Call UpdatePostureDeployment to update the deployment. Ensure that your
request includes the etag value from the GetPostureDeployment response. **
Important:** If you omit the etag when you call UpdatePostureDeployment,
then the updated deployment unconditionally overwrites the existing deployment.
394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/securityposture_v1/service.rb', line 394 def patch_organization_location_posture_deployment(name, posture_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecuritypostureV1::PostureDeployment::Representation command.request_object = posture_deployment_object command.response_representation = Google::Apis::SecuritypostureV1::Operation::Representation command.response_class = Google::Apis::SecuritypostureV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |